==> ant-design-vue-2.0.0-rc.9.jar: META-INF/resources/webjars/ant-design-vue/2.0.0-rc.9/es/page-header/index.d.ts <==
export declare const PageHeaderProps: {
    backIcon: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    title: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    subTitle: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    breadcrumb: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    tags: import("vue-types").VueTypeValidableDef<any>;
    footer: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    extra: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    avatar: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    ghost: import("vue-types").VueTypeValidableDef<boolean>;
    onBack: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
};
declare const _default: ({
    new (...args: any[]): {
        $: import("vue").ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        }> & Pick<Readonly<{
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        } & {
            footer?: import("../_util/type").VueNode;
            title?: import("../_util/type").VueNode;
            tags?: any;
            ghost?: boolean;
            extra?: import("../_util/type").VueNode;
            backIcon?: import("../_util/type").VueNode;
            subTitle?: import("../_util/type").VueNode;
        }> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, "style" | "class" | "footer" | "title" | "key" | "ref" | "onVnodeBeforeMount" | "onVnodeMounted" | "onVnodeBeforeUpdate" | "onVnodeUpdated" | "onVnodeBeforeUnmount" | "onVnodeUnmounted" | "tags" | "ghost" | "extra" | "backIcon" | "subTitle">;
        $attrs: Record<string, unknown>;
        $refs: Record<string, unknown>;
        $slots: Readonly<{
            [name: string]: import("vue").Slot;
        }>;
        $root: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $parent: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: import("vue").ComponentOptionsBase<Readonly<{
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        } & {
            footer?: import("../_util/type").VueNode;
            title?: import("../_util/type").VueNode;
            tags?: any;
            ghost?: boolean;
            extra?: import("../_util/type").VueNode;
            backIcon?: import("../_util/type").VueNode;
            subTitle?: import("../_util/type").VueNode;
        }>, {
            configProvider: import("../config-provider").ConfigConsumerProps;
        }, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        }>;
        $forceUpdate: import("vue").ReactiveEffect<any>;
        $nextTick: typeof import("vue").nextTick;
        $watch(source: string | Function, cb: Function, options?: import("vue").WatchOptions<boolean>): import("vue").WatchStopHandle;
    } & Readonly<{
        prefixCls: string;
        avatar: {
            [key: string]: any;
        };
        breadcrumb: {
            [key: string]: any;
        };
        onBack: (...args: any[]) => any;
    } & {
        footer?: import("../_util/type").VueNode;
        title?: import("../_util/type").VueNode;
        tags?: any;
        ghost?: boolean;
        extra?: import("../_util/type").VueNode;
        backIcon?: import("../_util/type").VueNode;
        subTitle?: import("../_util/type").VueNode;
    }> & import("vue").ShallowUnwrapRef<{
        configProvider: import("../config-provider").ConfigConsumerProps;
    }> & {} & import("vue").ComponentCustomProperties;
    __isFragment?: never;
    __isTeleport?: never;
    __isSuspense?: never;
} & import("vue").ComponentOptionsBase<Readonly<{
    prefixCls: string;
    avatar: {
        [key: string]: any;
    };
    breadcrumb: {
        [key: string]: any;
    };
    onBack: (...args: any[]) => any;
} & {
    footer?: import("../_util/type").VueNode;
    title?: import("../_util/type").VueNode;
    tags?: any;
    ghost?: boolean;
    extra?: import("../_util/type").VueNode;
    backIcon?: import("../_util/type").VueNode;
    subTitle?: import("../_util/type").VueNode;
}>, {
    configProvider: import("../config-provider").ConfigConsumerProps;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
    prefixCls: string;
    avatar: {
        [key: string]: any;
    };
    breadcrumb: {
        [key: string]: any;
    };
    onBack: (...args: any[]) => any;
}> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps & ((app: import("vue").App<any>, ...options: any[]) => any) & {
    install?: (app: import("vue").App<any>, ...options: any[]) => any;
}) | ({
    new (...args: any[]): {
        $: import("vue").ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        }> & Pick<Readonly<{
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        } & {
            footer?: import("../_util/type").VueNode;
            title?: import("../_util/type").VueNode;
            tags?: any;
            ghost?: boolean;
            extra?: import("../_util/type").VueNode;
            backIcon?: import("../_util/type").VueNode;
            subTitle?: import("../_util/type").VueNode;
        }> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, "style" | "class" | "footer" | "title" | "key" | "ref" | "onVnodeBeforeMount" | "onVnodeMounted" | "onVnodeBeforeUpdate" | "onVnodeUpdated" | "onVnodeBeforeUnmount" | "onVnodeUnmounted" | "tags" | "ghost" | "extra" | "backIcon" | "subTitle">;
        $attrs: Record<string, unknown>;
        $refs: Record<string, unknown>;
        $slots: Readonly<{
            [name: string]: import("vue").Slot;
        }>;
        $root: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $parent: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: import("vue").ComponentOptionsBase<Readonly<{
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        } & {
            footer?: import("../_util/type").VueNode;
            title?: import("../_util/type").VueNode;
            tags?: any;
            ghost?: boolean;
            extra?: import("../_util/type").VueNode;
            backIcon?: import("../_util/type").VueNode;
            subTitle?: import("../_util/type").VueNode;
        }>, {
            configProvider: import("../config-provider").ConfigConsumerProps;
        }, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        }>;
        $forceUpdate: import("vue").ReactiveEffect<any>;
        $nextTick: typeof import("vue").nextTick;
        $watch(source: string | Function, cb: Function, options?: import("vue").WatchOptions<boolean>): import("vue").WatchStopHandle;
    } & Readonly<{
        prefixCls: string;
        avatar: {
            [key: string]: any;
        };
        breadcrumb: {
            [key: string]: any;
        };
        onBack: (...args: any[]) => any;
    } & {
        footer?: import("../_util/type").VueNode;
        title?: import("../_util/type").VueNode;
        tags?: any;
        ghost?: boolean;
        extra?: import("../_util/type").VueNode;
        backIcon?: import("../_util/type").VueNode;
        subTitle?: import("../_util/type").VueNode;
    }> & import("vue").ShallowUnwrapRef<{
        configProvider: import("../config-provider").ConfigConsumerProps;
    }> & {} & import("vue").ComponentCustomProperties;
    __isFragment?: never;
    __isTeleport?: never;
    __isSuspense?: never;
} & import("vue").ComponentOptionsBase<Readonly<{
    prefixCls: string;
    avatar: {
        [key: string]: any;
    };
    breadcrumb: {
        [key: string]: any;
    };
    onBack: (...args: any[]) => any;
} & {
    footer?: import("../_util/type").VueNode;
    title?: import("../_util/type").VueNode;
    tags?: any;
    ghost?: boolean;
    extra?: import("../_util/type").VueNode;
    backIcon?: import("../_util/type").VueNode;
    subTitle?: import("../_util/type").VueNode;
}>, {
    configProvider: import("../config-provider").ConfigConsumerProps;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
    prefixCls: string;
    avatar: {
        [key: string]: any;
    };
    breadcrumb: {
        [key: string]: any;
    };
    onBack: (...args: any[]) => any;
}> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps & {
    install: (app: import("vue").App<any>, ...options: any[]) => any;
});
export default _default;

==> ant-design-vue-2.1.3.jar: META-INF/resources/webjars/ant-design-vue/2.1.3/es/page-header/index.d.ts <==
export declare const PageHeaderProps: {
    backIcon: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    title: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    subTitle: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    breadcrumb: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    tags: import("vue-types").VueTypeValidableDef<any>;
    footer: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    extra: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    avatar: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    ghost: import("vue-types").VueTypeValidableDef<boolean>;
    onBack: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
};
declare const _default: {
    new (...args: any[]): {
        $: import("vue").ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        }> & Omit<Readonly<{
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        } & {
            footer?: import("../_util/type").VueNode;
            title?: import("../_util/type").VueNode;
            tags?: any;
            ghost?: boolean;
            extra?: import("../_util/type").VueNode;
            backIcon?: import("../_util/type").VueNode;
            subTitle?: import("../_util/type").VueNode;
        }> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, "prefixCls" | "avatar" | "breadcrumb" | "onBack">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: import("vue").Slot;
        }>;
        $root: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $parent: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: import("vue").ComponentOptionsBase<Readonly<{
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        } & {
            footer?: import("../_util/type").VueNode;
            title?: import("../_util/type").VueNode;
            tags?: any;
            ghost?: boolean;
            extra?: import("../_util/type").VueNode;
            backIcon?: import("../_util/type").VueNode;
            subTitle?: import("../_util/type").VueNode;
        }>, {
            configProvider: import("../config-provider").ConfigConsumerProps;
        }, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
            prefixCls: string;
            avatar: {
                [key: string]: any;
            };
            breadcrumb: {
                [key: string]: any;
            };
            onBack: (...args: any[]) => any;
        }>;
        $forceUpdate: import("vue").ReactiveEffect<any>;
        $nextTick: typeof import("vue").nextTick;
        $watch(source: string | Function, cb: Function, options?: import("vue").WatchOptions<boolean>): import("vue").WatchStopHandle;
    } & Readonly<{
        prefixCls: string;
        avatar: {
            [key: string]: any;
        };
        breadcrumb: {
            [key: string]: any;
        };
        onBack: (...args: any[]) => any;
    } & {
        footer?: import("../_util/type").VueNode;
        title?: import("../_util/type").VueNode;
        tags?: any;
        ghost?: boolean;
        extra?: import("../_util/type").VueNode;
        backIcon?: import("../_util/type").VueNode;
        subTitle?: import("../_util/type").VueNode;
    }> & import("vue").ShallowUnwrapRef<{
        configProvider: import("../config-provider").ConfigConsumerProps;
    }> & {} & {} & import("vue").ComponentCustomProperties;
    __isFragment?: never;
    __isTeleport?: never;
    __isSuspense?: never;
} & import("vue").ComponentOptionsBase<Readonly<{
    prefixCls: string;
    avatar: {
        [key: string]: any;
    };
    breadcrumb: {
        [key: string]: any;
    };
    onBack: (...args: any[]) => any;
} & {
    footer?: import("../_util/type").VueNode;
    title?: import("../_util/type").VueNode;
    tags?: any;
    ghost?: boolean;
    extra?: import("../_util/type").VueNode;
    backIcon?: import("../_util/type").VueNode;
    subTitle?: import("../_util/type").VueNode;
}>, {
    configProvider: import("../config-provider").ConfigConsumerProps;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
    prefixCls: string;
    avatar: {
        [key: string]: any;
    };
    breadcrumb: {
        [key: string]: any;
    };
    onBack: (...args: any[]) => any;
}> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps & import("@vue/runtime-core").Plugin;
export default _default;
